@@ -17,10 +17,10 @@
 #define _PATH_UMOUNT "/bin/umount"
 #endif
 
-/* Standard function used by modules */
+/* Standard function used by daemon or modules */
 
 int spawnl(char *, ...);
-
+void reset_signals(void);
 
 /* Prototype for module functions */
 
